import { JWTPayload } from 'jose';
export declare class Cryptrack {
    private readonly _curve;
    private readonly _keys;
    private readonly _store;
    private readonly _jwtKeyPromise;
    private _jwtPublicJwk?;
    constructor();
    /**
     * Регистрирует сервис, вычисляет sharedKey и сохраняет его в памяти
     */
    register(id: string, publicKeyHex: string): string;
    /**
     * Возвращает sharedKey по id (если был ранее зарегистрирован)
     */
    getKey(id: string): string | undefined;
    /**
     * Шифрует строку с использованием sharedKey по id
     */
    encrypt(id: string, data: string): string;
    /**
     * Расшифровывает строку с использованием sharedKey по id
     */
    decrypt(id: string, encrypted: string): string;
    /**
     * Возвращает публичный ключ текущего Cryptrack-инстанса
     */
    getPublicKey(): string;
    /**
     * Подписывает JWT токен (используется внутренний ключ)
     */
    signToken(id: string, payload: Record<string, any>, expiresInSeconds?: string): Promise<string>;
    /**
     * Проверяет и декодирует JWT токен
     */
    verifyToken(token: string): Promise<{
        id: string;
        payload: JWTPayload;
    }>;
}
